# sense-hat-matrix
## Usage


## Dev
### Install project
   * `pip3 install -e . `

### Release new version
[Create new release with new `tag` on `github`](https://github.com/szigyi/sense-hat-matrix/releases/new)

